# -*- coding: utf-8 -*-
__version__ = '1.0.0'
__package_name__ = "kong-hmac"
__title__ = 'Kong 网关HMAC鉴权SDK'

__author__ = 'Jager'
__author_email__ = 'im@zhang.ge'

__license__ = 'Apache 2.0'

__python_requires__ = '>=2.6, <4'
__classifiers__ = ["Programming Language :: Python :: 3"]
__install_requires__ = []
__url__ = 'https://git.woa.com/nops/ngate/ngate-sdk/ngate-python.git'

__copyright__ = 'Copyright © zhang.ge. All Rights Reserved.'
__description__ = 'Kong 网关HMAC鉴权SDK'
